pub enum MultipartFormDataError {
NotFormDataError,
BoundaryNotFoundError,
IOError(Error),
MulterError(Error),
FromUtf8Error(FromUtf8Error),
DataTooLargeError(Arc<str>),
DataTypeError(Arc<str>),
}Expand description
Errors which may occur while parsing multipart/form-data.
Variants
NotFormDataError
The content type of the request is not multipart/form-data.
BoundaryNotFoundError
The content type of the request has no boundary parameter.
IOError(Error)
A temporary file cannot be created or written.
MulterError(Error)
The multipart stream is malformed, or one of the limits of multer is exceeded.
FromUtf8Error(FromUtf8Error)
The data of a text field is not valid UTF-8.
DataTooLargeError(Arc<str>)
The data of the field exceeds its size_limit.
DataTypeError(Arc<str>)
The content type of the field does not match any of its content type filters.